function main

%Function to integrate the mass and heat balance equations governing LNT operation
%Created by Kalyana Chakravarthy (ORNL), 9/27/2004
%Updated last by Kalyana Chakravarthy (ORNL), 9/27/2004

global Rgas mol_wt pressure
global diff_NO T_crit_NO diff_red T_crit_red 
global lambda_coeff lambda_exp lambda_solid 
global Cp_solid_0 Cp_solid_1 Cp_solid_2
global density_solid
global channel_length hole_fraction channel_density 
global wetted_area channel_diameter Sh Nu
global ncell dt odt dx odx nsteps

global delta_H1 delta_H2 
global temperature_storage temperature_scaling 
global rate_parameter1 rate_parameter2 rate_parameter3 rate_parameter4
global release_rate reduction_rate nitrite_fraction desorption_rate
global ppmNOx NOx_storage

%------------------------------------------------------------
% GAS PROPERTIES

[Rgas,mol_wt,diff_NO,T_crit_NO,diff_red,T_crit_red,lambda_coeff,lambda_exp,Cp_gas] = gas_properties;

%------------------------------------------------------------
% MONOLITH SPECIFICATIONS

[channel_length,hole_fraction,channel_density,density_solid,lambda_solid,Cp_solid_0,Cp_solid_1,Cp_solid_2,wetted_area,channel_diameter,Sh,Nu] = monolith_properties;

%------------------------------------------------------------
% DISCRETIZATION

[ncell,dt,odt,dx,odx,odx2] = discretization(channel_length);

%------------------------------------------------------------
% CATALYST PARAMETERS

[temperature_storage,rate_parameter1,rate_parameter2,rate_parameter3,rate_parameter4,temperature_scaling,release_rate,reduction_rate,nitrite_fraction,desorption_rate,ppmNOx,NOx_storage] = cat_specifications;

%------------------------------------------------------------
% LNT-IN DATA


[time,time_end,time_inflow,cinflow_NOx,cinflow_red,cinflow_O2,velocity,T_inflow,P_inflow] = inflow_data;

%------------------------------------------------------------
% INITIALIZATION LNT-IN DATA

[Tg,Ts,pressure,cg_NOx,cg_red,cg_O2,cw_NOx,cw_red,q] = initial_conditions(ncell);
 
%------------------------------------------------------------
% TIME-INTEGRATION USING FILTER APPROXIMATION

nprint = 0;
nsteps  = time_end/dt;

for ntime = 1:nsteps,

% 				INFLOW CONDITIONS FOR EACH STAGE

[cinput_NOx,cinput_red,cinput_O2,vel_in,Tinput,pressure,density_molar] = inflow_conditions(ncell,time_inflow,cinflow_NOx,cinflow_red,cinflow_O2,P_inflow,T_inflow,cg_NOx,cg_red,cg_O2,Tg,velocity,time);

% 				UPDATE IN TIME

[cg_NOx_old,cg_red_old,cg_O2_old,cw_NOx,cw_NOx_old,cw_red_old,q_old,Ts_old,Tg_old] = update(cg_NOx,cg_red,cg_O2,cw_NOx,cw_red,q,Ts,Tg,ncell,Rgas,pressure);

[dqdc]          = isotherm_slope(cw_NOx,Ts,pressure,Rgas,ncell);

for i = 1:ncell

vel             = vel_in*Tg(i)/Tinput(1);
density_molar	= pressure/Rgas/Tg(i);
fac             = exp(-dx*odt/vel);

%				O2 CONCENTRATION (computed using filter approximation)

cg_O2(i)        = cg_O2_old(i) + (cinput_O2(i) - cg_O2_old(i))*fac;
cinput_O2(i+1)  = cg_O2(i);
stoic		= (cg_O2(i) - 2*cinput_red(i))/density_molar;

if(stoic>1.0e-6) % 		LEAN CONDITION

% 				CAPTURE-PHASE MODEL

Dc_NOx          = diff_NO*(Tg(i)/T_crit_NO)^1.823;
rate_mt_NOx     = wetted_area*Sh*Dc_NOx/channel_diameter; % LAMINAR MT RATE

para1  		= interp1(temperature_storage,rate_parameter1,Ts(i));
para2           = interp1(temperature_storage,rate_parameter2,Ts(i));
para3           = interp1(temperature_storage,rate_parameter3,Ts(i));

rate_int	= para1 + (1.0 - para1)*exp(-para2*q(i));
rate_int	= para3*rate_int; % INTERNAL RATE (MASS TRANSFER + KINETICS)

rate_mt_NOx     = 1.0/(1.0/rate_mt_NOx + 1.0/rate_int); % EFFECTIVE NOx STORAGE RATE

alpha           = rate_mt_NOx*dqdc(i)*odt/(rate_mt_NOx + dqdc(i)*odt);
beta            = (alpha+odt)/vel;

fac             = exp(-beta*dx);
ctemp           = (cg_NOx_old(i) + alpha*dt*cw_NOx_old(i))/(1.0 + alpha*dt);

cg_NOx(i)       = ctemp + (cinput_NOx(i) - ctemp)*fac; % FILTER APPROX.
cg_red(i)       = cg_red(i)*0.0;

cmid		= (cinput_NOx(i) + cg_NOx(i))*0.5;
cw_NOx(i)	= (odt*dqdc(i)*cw_NOx_old(i) + rate_mt_NOx*cmid)*(rate_mt_NOx+dqdc(i)*odt)^-1;
q(i)	        = q_old(i) + dqdc(i)*(cw_NOx(i) - cw_NOx_old(i));

cinput_NOx(i+1) = cg_NOx(i);
cinput_red(i+1) = cg_red(i);
heat_release(i) = 0.0;

else	%			RICH CONDITION

%                               REGEN-PHASE MODEL

rate_r		= interp1(temperature_storage,release_rate,Ts(i)); % RELEASE RATE
rate_red	= interp1(temperature_storage,reduction_rate,Ts(i)); % REDUCTION RATE

for iter = 1:2	% SOLUTION OBTAINED ITERATIVELY (NUMBER OF ITERATION = 2 HERE)

cgred           = (cg_red(i) + cinput_red(i))*0.5;	% REDUCTANT AT MID-POINT OF CSTR
cgNOx		= (cg_NOx(i) + cinput_NOx(i))*0.5;	% NOx AT MID-POINT OF CSTR


Dc_red      	= diff_red*(Tg(i)/T_crit_red)^1.823;
rate_mt_red 	= wetted_area*Sh*Dc_red/channel_diameter; % LAMINAR MT RATE

release_stoic	= 1.5 - interp1(temperature_storage,nitrite_fraction,Ts(i));

alpha		= release_stoic*rate_r*q(i) + rate_red*cgNOx;

ratio_rates	= alpha/rate_mt_red;

if(ratio_rates>1.0) 	% COMPUTED REDUCTANT CONSUMPTION RATE EXCEED BL MASS TRANSFER
			% CORRECTION IS NEEDED

rate_r		= rate_r/ratio_rates;
rate_red	= rate_red/ratio_rates;
else
end

rate_d		= interp1(temperature_storage,desorption_rate,Ts(i)); %NOx DESORPTION RATE

q(i)            = q_old(i)*odt/(odt + rate_r*cgred + rate_d); %NOx STORAGE

alpha		= release_stoic*rate_r*q(i) + rate_red*cgNOx;
denom		= odt + vel*odx + 0.5*alpha;
rhs		= cg_red_old(i)*odt + vel*odx*cinput_red(i) - 0.5*alpha*cinput_red(i);

cg_red(i)	= max(rhs/denom,0);			    %GAS-PHASE REDUCTANT CONC.

alpha		= rate_red*cgred;
beta		= rate_r*q(i)*cgred + rate_d*q(i);

denom		= odt + vel*odx + 0.5*alpha;
rhs		= cg_NOx_old(i)*odt + vel*odx*cinput_NOx(i) - 0.5*alpha*cinput_NOx(i) + beta;

cg_NOx(i)	= max(rhs/denom,0);			     %GAS-PHASE NOx CONC.

cinput_NOx(i+1) = cg_NOx(i);
cinput_red(i+1) = cg_red(i);
 
end

heat_release(i)	= release_stoic*rate_r*q(i)*(cinput_red(i)+cg_red(i))*0.5*delta_H1 + rate_red*(cinput_red(i)+cg_red(i))*0.25*(cinput_NOx(i)+cg_NOx(i))*delta_H2;


end

%				HEAT-BALANCES 

density_gas	= pressure*mol_wt/Rgas/Tg(i);
Cp_solid	= Cp_solid_0 + Cp_solid_1*Ts(i) - Cp_solid_2/Ts(i)/Ts(i);

rate_ht		= Nu*lambda_coeff*(Tg(i)^lambda_exp)/channel_diameter;
rate_ht		= rate_ht*wetted_area;
rate_ht_gas	= rate_ht/hole_fraction/density_gas/Cp_gas;
rate_ht_solid	= rate_ht/(1-hole_fraction)/density_solid/Cp_solid;
thermal_cond	= lambda_solid/(1-hole_fraction)/density_solid/Cp_solid;

if(i==1) 
Tsleft		= Ts(i);
else
Tsleft		= Ts(i-1);
end

if(i==ncell)
Tsright		= Ts(i);
else
Tsright		= Ts(i+1);
end

heat_source1	= heat_release(i)/(1-hole_fraction)/density_solid/Cp_solid; 
				%EXOTHERMIC HEAT SOURCE IN T-EQUATION

heat_source2	= thermal_cond*(Tsleft+Tsright-2*Ts(i)); % CONDUCTION TERM

heat_source	= heat_source1 + heat_source2;

alpha		= rate_ht_gas/(1 + rate_ht_solid*dt);
beta		= heat_source*dt*rate_ht_gas/(1 + rate_ht_solid*dt);

denom		= odt + vel*odx + 0.5*alpha;
rhs     	= Tg_old(i)*odt + vel*odx*Tinput(i) - 0.5*alpha*Tinput(i) + beta + alpha*Ts_old(i);

Tg(i)		= max(rhs/denom,0.0);			%GAS TEMPERATURE

Tmid		= 0.5*(Tinput(i) + Tg(i));
Ts(i)		= (Tmid*rate_ht_solid + Ts_old(i)*odt + heat_source)/(odt+rate_ht_solid);

Tinput(i+1)	= Tg(i);

end

time = ntime*dt;
if(mod(ntime,10)==0) 
time
end

%				OUTPUT DATA

if(mod(ntime,1)==0) 
nprint = nprint + 1;

time_print(nprint) = time;
density_molar  = pressure/Rgas/Tg(ncell);
cexit_NOx(nprint)  = cg_NOx(ncell)*1.0e6/density_molar;
cexit_red(nprint)  = cg_red(ncell)*100/density_molar;
cexit_O2(nprint)   = cg_O2(ncell)*100/density_molar;
Tg_inlet(nprint)   = Tinput(1);
Tg_exit(nprint)    = Tg(ncell);

fppm   = [Tinput(1),Tg]*1.0e6*Rgas/pressure;
cplot1 = [cinput_NOx(1),cg_NOx].*fppm;
cplot  = [cinput_red(1),cg_red].*fppm;

mv(:,nprint,1) = cplot1;
mv(:,nprint,2) = cplot;

cplot = [Tinput(1),Tg];
cplot1= [Ts(1),Ts];

mv(:,nprint,3) = cplot;
mv(:,nprint,4) = cplot1;

cplot = [q(1),q];

mv(:,nprint,5) = cplot;

end
end

figure(1)
 
subplot(311)
plot(time_print,cexit_NOx)
%axis ([0 time 0 6.0e2]);
ylabel('exit NOx (ppm)')
title('Time-traces')
 
subplot(312)
plot(time_print,cexit_red,'-r',time_print,cexit_O2,'-b')
%axis ([0 time 0 0.15]);
ylabel('exit conc (%)')
legend('reductant','O2')
 
subplot(313)
plot(time_print,Tg_inlet,'-b',time_print,Tg_exit,'-r')
%axis ([0 time 675 725]);
ylabel('gas temperatures (K)')
legend('inlet','exit')
xlabel('time(s)')

figure(2)
plot(ppmNOx,NOx_storage)
%axis([0 500 0 150]);
ylabel('NOx stored (mol/m3)')
xlabel('NOx conc. (mol/m3)')
title('Isotherm shape')

figure(3)
plot(temperature_storage,temperature_scaling)
%axis([450 750 2 0.5])
ylabel('relative storage capacity')
xlabel('surface temperature (K)')
title('Variation of storage capacity with temperature')

rect = get(gcf,'Position');
rect(1:2) = [0 0];

nprint
for ipr = 1:nprint
xaxis  = [0:ncell]/ncell;
ipr
figure(4)
subplot(311)
plot(xaxis(:),mv(:,ipr,1),xaxis(:),mv(:,ipr,2))
ylabel ('species conc. (mol/m3)')
legend('NOx','reductant')
title('Spatial profiles')

subplot(312)
plot(xaxis(:),mv(:,ipr,3),xaxis(:),mv(:,ipr,4))
axis ([0 1 585 615]);
ylabel ('temperature (K)')
legend('bulk-flow','surface')

subplot(313)
plot(xaxis(:),mv(:,ipr,5))
axis ([0 1 0 75]);
xlabel('x/L (non-dimensional axial coordinate)')
ylabel ('NOx storage (mol/m3)')


M(:,ipr) = getframe(gcf,rect);
end 

clf
N = 1;
FPS = 10;
movie(gcf,M,N,FPS,rect)

