function [temperature_storage,rate_parameter1,rate_parameter2,rate_parameter3,rate_parameter4,temperature_scaling,release_rate,reduction_rate,nitrite_fraction,desorption_rate,ppmNOx,NOx_storage] = cat_specifications
%Function that defines LNT storage and rate characteristics
%Created by Kalyana Chakravarthy (ORNL), 9/27/2004
%Updated last by Kalyana Chakravarthy (ORNL), 9/27/2004
% Usage:
% [temperature_storage,rate_parameter1,rate_parameter2,rate_parameter3,rate_parameter4,temperature_scaling,release_rate,reduction_rate,nitrite_fraction,desorption_rate,ppmNOx,NOx_storage] = cat_specifications

global delta_H1 delta_H2
global temperature_storage temperature_scaling
global rate_parameter1 rate_parameter2 rate_parameter3 rate_parameter4
global release_rate reduction_rate nitrite_fraction desorption_rate
global ppmNOx NOx_storage

%------------------------------------
%Lean NOx storage isotherm specifications at 300C.
%Assumed to be measured at typical lean conditions for diesel exhaust with
% >4%O2.
%Specified as moles NOx stored/m^3 of monolith at saturation as a function of PPM NOx
%in gas.
ppmNOx = [ 0 2.06612 5.01771 6.98544 18.7918 37.5 77 110.291 138.823 168 206.71 245.081 278 315.919 351.338 387.741 425.128 460 ];
NOx_storage = [ 0 22.6013 46.9528 63.034 73.774 77.7344 79.8375 84.2658 90.485 94.9808 98.185 100.554 101.875 103.812 106.477 109.734 115.361 120.805 ];
%------------------------------------

%------------------------------------
%Temperatures for evaluating temperature effects on storage capacity and rate parameters
temperature_storage = [ 189 212 239 267 295 334 354 384 415 446 ]; %Temperature points in deg C
temperature_storage = temperature_storage + 273.16; %Temperature points converted to Kelvin
%------------------------------------

%------------------------------------
%Temperature effects on lean NOx storage isotherm.

temperature_scaling = [ 1.832916 1.571355 1.334881 1.146751 1.000000 0.8796051 0.7799695 0.6992549 0.6308971 0.5742939];

% Isotherm defined at 300C is scaled to obtain isotherm at other temperatures 
% (a factor >1 implies higher capacity). Isotherm capacity varies 
% as exp(-constant/temperature)

nitrite_fraction= [1.0 0.87 0.5 0.263 0.09 0.15 0.2176 0.311 0.42 0.57];
%Fraction of stored NOx as nitrite (versus nitrate).
%------------------------------------

%------------------------------------
%Lean storage rate parameters as functions of temperature.
%Used in rate_int = rate_parameter3*[rate_parameter1 + (1-rate_parameter1)*exp(-rate_parameter2*q)]
% q is moles NOx stored/m^3 of monolith.

rate_parameter1 = [ 0.00156 0.0173 0.0334 0.027008 0.01492 0.00607 0.00247 0.00109 0.00159916 0.00227 ];
%Ratio of terminal (approaching saturation) to initial rates of storage.

rate_parameter2 = [ 0.0511 0.0611 0.0674 0.0563044 0.0409 0.0456  0.0511 0.0608 0.0796164 0.0971 ];
%Characterizes the exponential decrease of NOx storage rate as material approaches saturation.
%Units are m^3/mole NOx.

rate_parameter3 = [ 117 145 189 174 145 171 180 202 251 275 ];
%Initial global rate constant for NOx storage at zero loading and in
%absence of boundary-layer mass transfer resistance. Units are 1/s.
%-----------------------------------

%-----------------------------------
%Regeneration rate parameters as functions of temperature

release_rate = [0.599621 0.716 1.00154 1.23 1.66 1.75 1.78335 2.22 3.12 3.83];
release_rate = release_rate*0.9;
%Rate parameters for reductant stimulated NOx release, m^3/(mole s)

reduction_rate= [0.836532 0.9822 1.54643 2.03 3.16 2.32 1.59382 1.42 1.35 1.34];
reduction_rate= 1.6e4*reduction_rate;
%Rate parameters for reduction of released NOx, m^3/(mole s)

desorption_rate=[0 0 5.6977e-05 0.000113836 0.000187 0.0002 0.0002086 0.000282 0.00075 0.00139];
%Rate parameter for thermally driven NOx release, 1/s
%----------------------------------

%----------------------------------
%Heat release parameters
delta_H1 = 1.0e5; %Heat generated by NOx release (J/mole NOx released)
delta_H2 = 6.5e4; %Heat generated by NOx reduction (J/mole NOx reduced)
%----------------------------------
